
.ellipsis {
  position: relative;
}

.ellipsis:before {
  content: '&nbsp;';
  visibility: hidden;
}

.ellipsis span {
  position: absolute;
  left: 0;
  right: 0;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}

.card {
  border-radius: 0px;
  border: 1px solid var(--border-color);
  box-sizing: border-box;
  min-height: 8rem;
  height: 100%;
}

.title {
  color: var(--title-color);
  margin-bottom: 0;
}
.card-title {
  text-decoration: none;
  font-style: normal;
  font-weight: bold;
  text-align: left;
  font-size: var(--title-size);
}

.card-content {
  font-style: normal;
  font-weight: normal;
  color: var(--value-color);
  text-decoration: none;
  padding: 0rem 0rem;
  font-size: var(--value-size);
}

.content-row {
  margin-top: 30px;
}

.header-row {
  margin: 0rem 0rem;
  text-align: center;
  padding-top: 0;
  padding-bottom: 0;
  line-height: 1.3;
}

.info-icon {
  text-align: center;
  font-size: var(--icon-size);
  color:var(--icon-color);
  opacity:var(--icon-opacity);
}

.progressbar {
  width: var(--progress-value); 
  height: 7vh;
  background-color: var(--progress-color);
  border: 1px solid #E0E6EB;
  position: absolute;
  bottom: 0px;
}

.kpi {
  padding: 0rem 0rem;
  margin: 0.3rem;
  border-spacing: 0;
  border-collapse: collapse;
  height: inherit;
}

.nopad{
  padding: 0px;
}